#include <miemath.h>

extern double DSun        //declinazione del sole in radianti
extern double latitud;    //latitudine in gradi
extern double longitud;   //longitudine in gradi
extern double FusoOrario; //Fuso Orario (italia -1) in ore
extern double ET;         //Equazione del tempo in minuti
extern double alfa;       //Ascensione Retta del Sole
extern double DSun;       //Declinazione del Sole
extern double HOrario;    //Angolo Orario del Sole



//
//        by Diego Bonata 1997
//
// FUNZIONE      : JD
// VAR.PASSATE   : (double) anno, mese, giorno
// VAR.RESTITUITE: (double) giorno giuliano
// INCLUDE       : math.h
// DESCRIZIONE   :
// Routile di calcolo del giorno giuliano
double JD (double dat,double mese,double giorno);

//
//        by Diego Bonata 1997
//
// FUNZIONE      : jtog
// VAR.PASSATE   : (double) giorno giuliano
// VAR.RESTITUITE: (int) mese, giorno, ora, minuti
// INCLUDE       : math.h
// DESCRIZIONE   :
// Routile di calcolo di mese,giorno,ora,minutinoto il giorno giuliano
void jtog(double jd,int *m,int *g,int *h,int *mi);

//
//        by Diego Bonata 1997
//
// FUNZIONE      : sortra
// VAR.PASSATE   : (float) Yeasr,Month,Day= anno, mese, giorno
// VAR.RESTITUITE: (float) *sorge   = ora del sorgere del sole in ore
//                 (float) *tramonta= ora del tramonto del sole in ore
// INCLUDE       : math.h
// DESCRIZIONE   :
// Routile di CALCOLO DELL' ORA DEL SORGERE E DEL TRAMONTO: NON PORTABILE
// Valori inseriti nelle variabili sorge, tramonta
void sortra(float Year,float Month,float Day,float *sorge,float *tramonta);

//
//        by Diego Bonata 1997
//
// FUNZIONE      : sortra
// VAR.PASSATE   : (double) jday = giorno giuliano per la data desiderata
//                 (double) ora  = ora desiderata
//                 (int) f_ET    = Flag di selezione se f_ET= 2 calcola
//                 l'Equazione del tempo in caso contrario le coord. del Sole
// VAR.RESTITUITE: (double) ET   = Equazione del Tempo in minuti (se f_ET=2)
//                 (double) alfa = Ascensione Retta del sole
//                 (double) DSun = Declinazione del sole
//                 (double) HOrario = Angolo Orario del sole
// INCLUDE       : miemath.h
// DESCRIZIONE   :
// Calcolo delle coordinate del sole e dell'Equazione del tempo del sole
// in un determinato istante
// FUNZIONI DI SUPPORTO: CalcT, LongMed, AnoMed, Centro, CalcOmega, LongApp
// CalcObli, Eccentric, CalcSidTime, ConvHO
void calcola_posizione_sole(register double jday,double ora,int f_ET);

double CalcT (double jday);

//Longitudine media del sole
double LongMed (register double T);

//Anomalia Media del sole
double AnoMed (register double T);

//Eccentricit
double Eccentric (register double T);

//Centro
double Centro (register double AM,register double T);

double CalcOmega (register double T);

//Longitudine apparente del sole
double LongApp (register double LVs, register double omega);

//Obliquit dell'eclittica
double CalcObli (register double omega, register double T);

//rende giusto il valore di HOrario
void ConvHO(double ora);

//
//        by Diego Bonata 1997
//
// FUNZIONE      : CalcSidTime
// VAR.PASSATE   : (double) T   = secoli giuliani calcolati mediante il
//                 giorno giuliano con CalcT
//                 (double) ora = ora desiderata
// VAR.RESTITUITE: (double) Ora Siderale
// INCLUDE       : miemath.h
// DESCRIZIONE   :
// Calcolo delle coordinate del sole e dell'Equazione del tempo del sole
// in un determinato istante
// FUNZIONI DI SUPPORTO: CalcT, LongMed, AnoMed, Centro, CalcOmega, LongApp
// CalcObli, Eccentric, CalcSidTime, ConvHO
//Tempo Siderale per l'ora desiderata
double CalcSidTime (register double T, double ora);
